@@ -321,14 +321,17 @@ A minimal implementation of this method would look like::
         return None, None
 
 Most GUI frameworks are providing classes that need to
-be instantiated for the application and for each window.
+be instantiated for the application, the root layout of the app
+and for each window.
 For to keep a reference to these instances within your main app class
-you can use the attributes :attr:`~MainAppBase.framework_app`
-and :attr:`~MainAppBase.framework_win` of :class:`MainAppBase`.
+you can use the attributes :attr:`~MainAppBase.framework_app`,
+:attr:`~MainAppBase.framework_root` and
+:attr:`~MainAppBase.framework_win` of :class:`MainAppBase`.
 
-The initialization of the attributes :attr:`~MainAppBase.framework_app`
-and :attr:`~MainAppBase.framework_win` is optional and can be
-done e.g. within :meth:`~MainAppBase.init_app`.
+The initialization of the attributes :attr:`~MainAppBase.framework_app`,
+:attr:`~MainAppBase.framework_root` and :attr:`~MainAppBase.framework_win`
+is optional and can be done e.g. within :meth:`~MainAppBase.init_app`
+or in the later called `build` method of the framework app instance.
 
 .. note::
     If :attr:`~MainAppBase.framework_win` is set to a window instance,
@@ -376,17 +379,17 @@ from abc import ABC, abstractmethod
 import re
 import traceback
 from copy import deepcopy
-from typing import Any, Callable, Dict, Tuple, List, Optional, Type, Sequence
+from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Type
 
-from ae.core import DEBUG_LEVELS, stack_var         # type: ignore
-from ae.updater import check_all                    # type: ignore
-from ae.console import ConsoleApp                   # type: ignore
+from ae.core import DEBUG_LEVELS, stack_var                         # type: ignore
+from ae.updater import check_all                                    # type: ignore
+from ae.console import ConsoleApp                                   # type: ignore
 
-from ae.files import FilesRegister, RegisteredFile  # type: ignore
-from ae.i18n import default_language                # type: ignore
+from ae.files import FilesRegister, RegisteredFile                  # type: ignore
+from ae.i18n import default_language                                # type: ignore
 
 
-__version__ = '0.0.29'
+__version__ = '0.0.30'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -530,6 +533,7 @@ class MainAppBase(ConsoleApp, ABC):
     # optional generic run-time shortcut references
     framework_app: Any = None                               #: app class instance of the used GUI framework
     framework_win: Any = None                               #: window instance of the used GUI framework
+    framework_root: Any = None                              #: app root layout widget
 
     # optional app resources caches
     image_files: Optional[FilesRegister] = None             #: image/icon files
@@ -580,29 +584,32 @@ class MainAppBase(ConsoleApp, ABC):
     def change_app_state(self, state_name: str, new_value: Any, send_event: bool = True):
         """ change single app state item to new_value in self.attribute and app_state dict item.
 
-        :param state_name:  name of the app state to change.
-        :param new_value:   new value of the app state to change.
-        :param send_event:  pass False to prevent to send/call the on_<state_name> event to the main app instance.
+        :param state_name:      name of the app state to change.
+        :param new_value:       new value of the app state to change.
+        :param send_event:      pass False to prevent to send/call the on_<state_name> event to the main app instance.
         """
         self.vpo(f"MainAppBase.change_app_state({state_name}, {new_value}, {send_event})"
                  f" flow={self.flow_id} last={self._last_focus_flow_id} path={self.flow_path}")
-        setattr(self, state_name, new_value)
-        self._change_observable(state_name, new_value)
+        self.change_observable(state_name, new_value, is_app_state=True)
         if send_event:
             self.call_method('on_' + state_name)
 
-    def _change_observable(self, name: str, value: Any):
-        """ change observable attribute/member/property in framework_app instance.
+    def change_observable(self, name: str, value: Any, is_app_state: bool = False):
+        """ change observable attribute/member/property in framework_app instance (and shadow copy in main app).
 
-        :param name:        name of the observable attribute/member or key of an observable dict property.
-        :param value:       new value of the observable.
+        :param name:            name of the observable attribute/member or key of an observable dict property.
+        :param value:           new value of the observable.
+        :param is_app_state:    pass True for an app state observable.
         """
+        setattr(self, name, value)
         if self.framework_app:
-            if hasattr(self.framework_app, 'ae_states'):            # has observable DictProperty duplicates
-                # noinspection PyUnresolvedReferences
-                self.framework_app.ae_states[name] = value
-            if hasattr(self.framework_app, 'ae_state_' + name):     # has observable attribute duplicate
-                setattr(self.framework_app, 'ae_state_' + name, value)
+            if is_app_state:
+                if hasattr(self.framework_app, 'ae_states'):        # has observable DictProperty duplicates
+                    # noinspection PyUnresolvedReferences
+                    self.framework_app.ae_states[name] = value
+                name = 'ae_state_' + name
+            if hasattr(self.framework_app, name):                   # has observable attribute duplicate
+                setattr(self.framework_app, name, value)
 
     def load_app_states(self):
         """ load application state for to prepare app.run_app """
@@ -757,7 +764,7 @@ class MainAppBase(ConsoleApp, ABC):
         """
         if self.framework_app:
             for key, val in app_state.items():
-                self._change_observable(key, val)
+                self.change_observable(key, val, is_app_state=True)
 
     # flow helper methods
 
@@ -817,7 +824,7 @@ class MainAppBase(ConsoleApp, ABC):
             # dismiss gets sent sometimes twice (e.g. on heavy double-clicking on drop-down-open-buttons)
             # .. therefore prevent run-time error
             if not self.flow_path:
-                self.dpo(f"MainAppBase.change_flow: ignoring multiple close action '{action}'")
+                self.dpo(f"MainAppBase.change_flow: ignoring multiple dismiss on empty flow path; action='{action}'")
                 return False
             ended_flow_id = self.flow_path.pop()
             self.change_app_state('flow_path', self.flow_path)
@@ -843,6 +850,7 @@ class MainAppBase(ConsoleApp, ABC):
 
         self.vpo(f"MainAppBase.change_flow CHANGED '{new_flow_id}';"
                  f" flow='{self.flow_id}' last='{self._last_focus_flow_id}' path={self.flow_path}")
+
         return True
 
     def flow_path_action(self, path_index: int = -1) -> str:
@@ -892,7 +900,7 @@ class MainAppBase(ConsoleApp, ABC):
             assert callable(event_callback), f"MainAppBase.call_method: {method!r} is not callable ({args}, {kwargs})"
             try:
                 return event_callback(*args, **kwargs)
-            except (AttributeError, LookupError, ValueError) as ex:
+            except (AttributeError, IndexError, LookupError, ValueError, Exception) as ex:
                 self.po(f" ***  MainAppBase.call_method({method}, {args}, {kwargs}): {ex}\n{traceback.format_exc()}")
         return None
 
